title = "Ophelia example site"

This is the index page of the Ophelia example site located at http://www.thomas-lotze.de/software/ophelia/example/.

Take a look at the foo, foo/bar, and foo/baz pages as well as the asdf folder.

This hypothetical Apache2 configuration would publish the example site at its proper URL, .../ophelia/ being the file system path to a copy of the Ophelia source:

    Alias /software/ophelia/example .../ophelia/example/static
    <Location "/software/ophelia/example">
        PythonInterpreter main_interpreter
        PythonPath "['.../ophelia'] + sys.path"
        PythonOption template_root .../ophelia/example/ophelia_pages
        PythonOption site http://www.thomas-lotze.de/software/ophelia/example
        PythonFixupHandler ophelia.modpython
    </Location>